@@ -18,6 +18,7 @@ class KWinWaylandBackend : public InputBackend
     Q_OBJECT
 
     Q_PROPERTY(int deviceCount READ deviceCount CONSTANT)
+    Q_PROPERTY(QVariantMap buttonMapping READ buttonMapping WRITE setButtonMapping NOTIFY buttonMappingChanged)
 
 public:
     explicit KWinWaylandBackend(QObject *parent = nullptr);
@@ -41,6 +42,12 @@ public:
         return m_devices;
     }
 
+    QVariantMap buttonMapping();
+    void setButtonMapping(const QVariantMap &mapping);
+
+Q_SIGNALS:
+    void buttonMappingChanged();
+
 private Q_SLOTS:
     void onDeviceAdded(QString);
     void onDeviceRemoved(QString);
@@ -50,6 +57,8 @@ private:
 
     QDBusInterface *m_deviceManager;
     QVector<QObject *> m_devices;
+    QVariantMap m_buttonMapping;
+    QVariantMap m_loadedButtonMapping;
 
     QString m_errorString = QString();
 };
